@@ -276,6 +276,7 @@ sub is_authorized {
 
     # login bypass
     $meta->set('META_LOGIN_BYPASS_STATE', 0) if not defined $meta->META_LOGIN_BYPASS_STATE;
+    return 1 if $site->MFILE_WWW_BYPASS_LOGIN_DIALOG and $meta->META_LOGIN_BYPASS_STATE;
     if ( $site->MFILE_WWW_BYPASS_LOGIN_DIALOG and not $meta->META_LOGIN_BYPASS_STATE ) {
         $log->notice("Bypassing login dialog! Using default credentials");
         $session->{'ip_addr'} = $remote_addr;
@@ -408,9 +409,9 @@ sub main_html {
     $r .= '<html>';
     $r .= '<head>';
     $r .= '<meta charset="utf-8">';
-    $r .= '<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">';
-    $r .= '<meta http-equiv="Pragma" content="no-cache">';
-    $r .= '<meta http-equiv="Expires" content="0">';
+#    $r .= '<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">';
+#    $r .= '<meta http-equiv="Pragma" content="no-cache">';
+#    $r .= '<meta http-equiv="Expires" content="0">';
     $r .= "<title>App::MFILE::WWW " . $meta->META_MFILE_APPVERSION . "</title>";
     $r .= '<link rel="stylesheet" type="text/css" href="/css/start.css" />';
 
@@ -419,6 +420,7 @@ sub main_html {
 
     $r .= '</head>';
     $r .= '<body>';
+    $r .= '<div id="myLoadProgress" class="loadProgress">Loading RequireJS...</div>';
 
     # Start the main app logic
     $r .= '<script>require([\'main\']);</script>';
@@ -466,6 +468,7 @@ sub test_html {
     $r .= $self->_require_js(1);
 
     $r .= '</head><body>';
+    $r .= '<div id="myLoadProgress" class="loadProgress">Loading RequireJS...</div>';
     $r .= '<div id="qunit"></div>';
     $r .= '<div id="qunit-fixture"></div>';
 
@@ -503,6 +506,25 @@ sub _require_js {
     $r .= "    'jquery-private': { 'jquery': 'jquery' }";
     $r .= '},';
 
+    # callbacks for showing module loading progress
+    $r .= 'onNodeCreated: function(node, config, moduleName, url) {';
+    $r .= "    var t = document.getElementById('myLoadProgress'),";
+    $r .= "        m = '';";
+    $r .= "    m = 'module ' + moduleName + ' is about to be loaded';";
+    $r .= "    console.log(m);";
+    $r .= "    t.innerHTML = m;";
+    $r .= "    node.addEventListener('load', function() {";
+    $r .= "        m = 'module ' + moduleName + ' has been loaded';";
+    $r .= "        console.log(m);";
+    $r .= "        t.innerHTML = m;";
+    $r .= '    });';
+    $r .= "    node.addEventListener('error', function() {";
+    $r .= "        m = 'module ' + moduleName + ' could not be loaded';";
+    $r .= "        console.log(m);";
+    $r .= "        t.innerHTML = m;";
+    $r .= '    });';
+    $r .= '},';
+
     # path config
     $r .= 'paths: {';
     $r .= '    "app": "../' . $site->MFILE_APPNAME . '",';  # sibling to baseUrl
@@ -521,7 +543,10 @@ sub _require_js {
     $r .= '            QUnit.config.autostart = false;';
     $r .= '        }';
     $r .= '    }';
-    $r .= '}';
+    $r .= '},';
+
+    # default waitSeconds is just 7, which is too little for production
+    $r .= 'waitSeconds: 30';
 
     # end of require.config
     $r .= "});";
