@@ -101,9 +101,9 @@ define ([
         },
         dmenuKeyListener = function (dmn) {
             return function (event) {
-                coreLib.logKeyPress(event);
+                coreLib.logKeyDown(event);
                 if (event.keyCode === 13) {
-                    console.log("Detected ENTER keypress; submitting " + dmn + " form");
+                    console.log("Detected ENTER keydown; submitting " + dmn + " form");
                     event.preventDefault();
                     dmenuSubmit(dmn);
                 } else if (event.keyCode === 9) {
@@ -153,7 +153,7 @@ define ([
                 n = $("input:text").index($(document.activeElement)),
                 i;
 
-            coreLib.logKeyPress(evt);
+            coreLib.logKeyDown(evt);
             coreLib.clearResult();
     
             if (evt.keyCode === 13) {
@@ -179,10 +179,12 @@ define ([
                         (elnam === 'sel' && len === 1) ||
                         (elnam === 'sel' && !evt.shiftKey)
                    ) {
-                    // prevent TAB keypress from navigating out of the form
+                    // prevent TAB keydown from navigating out of the form
                     evt.preventDefault();
                 }
-                mmKeyListenerVetEntry(evt, n, elid);
+                if (! evt.shiftKey) {
+                    mmKeyListenerVetEntry(evt, n, elid);
+                }
             }
 
         },
@@ -269,7 +271,7 @@ define ([
         dformListen = function (dfn, obj, focusId) {
             console.log("Listening in form " + dfn);
             currentTarget = target.pull(dfn);
-            $('#' + dfn).submit( suppressSubmitEvent );
+            $('#' + dfn).submit(suppressSubmitEvent);
             $('input[name="sel"]').val('');
             if (focusId) {
                 $('input[id="' + focusId + '"]').focus();
@@ -283,7 +285,7 @@ define ([
                 console.log("Submitting form " + dfn);
                 mmSubmit(obj);
             });
-            $('#' + dfn).on("keypress", mmKeyListener);
+            $('#' + dfn).on("keydown", mmKeyListener);
         },
 
         //
@@ -301,19 +303,19 @@ define ([
             
             return function (evt) {
         
-                coreLib.logKeyPress(evt);
+                coreLib.logKeyDown(evt);
         
                 // since the dbrowser has (may have) a navigation menu, we
                 // check first for those keys before moving to miniMenu handler
                 if (evt.keyCode === 37) { // <-
                     if (evt.ctrlKey) {
-                        console.log('Listener detected CTRL-\u2190 keypress');
+                        console.log('Listener detected CTRL-\u2190 keydown');
                         if ($("#navJumpToBegin").length) {
                             coreLib.dbrowserState.pos = 0;
                             dbrowserListen();
                         }
                     } else {
-                        console.log('Listener detected \u2190 keypress');
+                        console.log('Listener detected \u2190 keydown');
                         if ($("#navBack").length) {
                             coreLib.dbrowserState.pos -= 1;
                             dbrowserListen();
@@ -321,13 +323,13 @@ define ([
                     }
                 } else if (evt.keyCode === 39) { // ->
                     if (evt.ctrlKey) {
-                        console.log('Listener detected CTRL-\u2192 keypress');
+                        console.log('Listener detected CTRL-\u2192 keydown');
                         if ($("#navJumpToEnd").length) {
                             coreLib.dbrowserState.pos = set.length - 1;
                             dbrowserListen();
                         }
                     } else {
-                        console.log('Listener detected \u2192 keypress');
+                        console.log('Listener detected \u2192 keydown');
                         if ($("#navForward").length) {
                             coreLib.dbrowserState.pos += 1;
                             dbrowserListen();
@@ -361,7 +363,7 @@ define ([
                 stack.getState().pos = pos;
                 dbrowserSubmit();
             });
-            $('#' + dbo.name).on("keypress", dbrowserKeyListener());
+            $('#' + dbo.name).on("keydown", dbrowserKeyListener());
         },
 
         //
@@ -374,7 +376,7 @@ define ([
                 stack.pop();
                 return;
             });
-            $('#' + dno.name).on("keypress", mmKeyListener);
+            $('#' + dno.name).on("keydown", mmKeyListener);
         },
 
         //
@@ -393,7 +395,7 @@ define ([
                 //console.log("Submitting table " + dto.name);
                 dtableSubmit(dto);
             });
-            $('#' + dto.name).on("keypress", mmKeyListener);
+            $('#' + dto.name).on("keydown", mmKeyListener);
         },
 
         //
@@ -431,16 +433,16 @@ define ([
             return function (evt) {
 
                 console.log("Entering drowselectKeyListener");
-                coreLib.logKeyPress(evt);
+                coreLib.logKeyDown(evt);
 
                 if (evt.keyCode === 37) { // up arrow
                     if (evt.ctrlKey) {
-                        console.log('Listener detected CTRL-up arrow keypress');
+                        console.log('Listener detected CTRL-up arrow keydown');
                         coreLib.reverseVideo(coreLib.drowselectState.pos, false);
                         coreLib.drowselectState.pos = 0;
                         drowselectListen();
                     } else {
-                        console.log('Listener detected up arrow keypress');
+                        console.log('Listener detected up arrow keydown');
                         if (coreLib.drowselectState.pos > 0) {
                             coreLib.reverseVideo(coreLib.drowselectState.pos, false);
                             coreLib.drowselectState.pos -= 1;
@@ -449,12 +451,12 @@ define ([
                     }
                 } else if (evt.keyCode === 39) { // down arrow
                     if (evt.ctrlKey) {
-                        console.log('Listener detected CTRL-down arrow keypress');
+                        console.log('Listener detected CTRL-down arrow keydown');
                         coreLib.reverseVideo(coreLib.drowselectState.pos, false);
                         coreLib.drowselectState.pos = set.length - 1;
                         drowselectListen();
                     } else {
-                        console.log('Listener detected down arrow keypress');
+                        console.log('Listener detected down arrow keydown');
                         if (coreLib.drowselectState.pos < set.length - 1) {
                             coreLib.reverseVideo(coreLib.drowselectState.pos, false);
                             coreLib.drowselectState.pos += 1;
@@ -482,7 +484,7 @@ define ([
                 //console.log("Submitting rowselect " + drso.name);
                 drowselectSubmit();
             });
-            $('#' + drso.name).on("keypress", drowselectKeyListener());
+            $('#' + drso.name).on("keydown", drowselectKeyListener());
         };
 
     return {
@@ -506,17 +508,33 @@ define ([
             var dfo = target.pull(dfn);
             return function (state, opts) {
                 console.log('Entering start method of target ' + dfn);
+                var i,
+                    populateArray = [];
                 if (typeof opts !== 'object') {
                     opts = {};
                 }
                 opts.resultLine = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
                 opts.inputId = ('inputId' in opts) ? opts.inputId : null;
                 coreLib.displayResult(opts.resultLine);
+                // determine dform "state" (i.e. starting content of form entries)
                 if (! state) {
                     state = stack.getState();
                 }
                 console.log('The object we are working with is:', state);
+                // generate and display dform html
                 $('#mainarea').html(dfo.source(state));
+                // assemble array of entries with "populate" property
+                for (i = 0; i < dfo.entriesRead.length; i += 1) {
+                    if (dfo.entriesRead[i].hasOwnProperty("populate")) {
+                        populateArray.push(dfo.entriesRead[i].populate);
+                    }
+                }
+                // call first populate function to trigger sequential,
+                // asynchronous population of all entries with "populate" property
+                if (populateArray.length > 0) {
+                    populateArray[0](populateArray);
+                }
+                // listen for user input in form
                 dformListen(dfn, state, opts.inputId);
             };
         }, // dform
